@@ -43,7 +43,7 @@ class mock_api:
             self.attributes = attributes
 
     def send(self,port,msg):
-        mock_api.msg_list.append({'port':port,'data':msg})
+        mock_api.msg_list.append({'port':port,'dev_data':msg})
         if mock_api.print_send_msg :
             if isinstance(msg,str) :
                 print('PORT {}: {}'.format(port,msg))
